@@ -1,13 +1,15 @@
 package Mail::AuthenticationResults::Header::Comment;
+require 5.010;
 use strict;
 use warnings;
-our $VERSION = '1.20171226'; # VERSION
+our $VERSION = '1.20171230'; # VERSION
 use Scalar::Util qw{ weaken };
-
-sub HAS_VALUE{ return 1; }
+use Carp;
 
 use base 'Mail::AuthenticationResults::Header::Base';
 
+sub HAS_VALUE{ return 1; }
+
 sub set_value {
     my ( $self, $value ) = @_;
 
@@ -18,10 +20,9 @@ sub set_value {
         $remain   = substr( $remain,1 );
         $depth++ if $first eq '(';
         $depth-- if $first eq ')';
-        die 'Out of order parent in comment' if $depth == -1;
+        croak 'Out of order parent in comment' if $depth == -1;
     }
-    die 'Mismatched parens in comment' if $depth != 0;
-
+    croak 'Mismatched parens in comment' if $depth != 0;
 
     $self->{ 'value' } = $value;
     return $self;
